aboutsummaryrefslogtreecommitdiffstats
path: root/build/plugins
diff options
context:
space:
mode:
authornechda <nechda@yandex-team.com>2024-11-19 22:47:26 +0300
committernechda <nechda@yandex-team.com>2024-11-19 22:59:42 +0300
commit5d885b87d95d69c68611be5aef800f5ff90f42a8 (patch)
treeab952c754d3df7f31b7aa169317aa3e94152f2bc /build/plugins
parent7297d051e885fd49e3a809f5181df9d4368cbe23 (diff)
downloadydb-5d885b87d95d69c68611be5aef800f5ff90f42a8.tar.gz
Add suppressions for ubsan in openssl
commit_hash:54d8848f6168c0370b9bcbd164290fc4fc1c2128
Diffstat (limited to 'build/plugins')
-rw-r--r--build/plugins/suppressions.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/build/plugins/suppressions.py b/build/plugins/suppressions.py
index db5037646d..a661e8a621 100644
--- a/build/plugins/suppressions.py
+++ b/build/plugins/suppressions.py
@@ -2,16 +2,17 @@ def onsuppressions(unit, *args):
"""
SUPPRESSIONS() - allows to specify files with suppression notation which will be used by
address, leak or thread sanitizer runtime by default.
- Use asan.supp filename for address sanitizer, lsan.supp for leak sanitizer
- and tsan.supp for thread sanitizer suppressions respectively.
+ Use asan.supp filename for address sanitizer, lsan.supp for leak sanitizer,
+ ubsan.supp for undefined behavior sanitizer and tsan.supp for thread sanitizer
+ suppressions respectively.
See https://clang.llvm.org/docs/AddressSanitizer.html#suppressing-memory-leaks
for details.
"""
import os
- valid = ("asan.supp", "tsan.supp", "lsan.supp")
+ valid = ("asan.supp", "tsan.supp", "lsan.supp", "ubsan.supp")
- if unit.get("SANITIZER_TYPE") in ("leak", "address", "thread"):
+ if unit.get("SANITIZER_TYPE") in ("leak", "address", "thread", "undefined"):
for x in args:
if os.path.basename(x) not in valid:
unit.message(